Files
project_6/cccl_upstream/cudax/test/stf/graph/explicit_graph.cu
muh-bot dedf08166a [CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout:
- c2h/ (27 files): Catch2 test helpers — generators, validators, runner
- nvbench_helper/ (10 files): Benchmark harness utilities
- cmake/ (29 files): CMake presets and build helpers
- cudax/ (794 files): Experimental CUDA extensions
- AGENTS.md: NVIDIA's official AI agent instructions for CCCL
- CMakePresets.json: Standardized build configurations
- cccl-version.json: Version tracking

Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to
competition value and PRD items.

cccl_upstream now covers 100% of competition-critical assets:
- 27 tuning headers (SM80/90/100 benchmark data)
- 32 dispatch headers (algorithm implementations)
- 60 Thrust examples (correctness verification)
- 217 CUB Catch2 tests (regression matrix)
- 153 CUB benchmarks (parameter space search)
- 18 CUB examples (API verification)
- 27 test helpers + benchmark harness
- 794 cudax experimental extensions
2026-08-06 02:14:18 +00:00

58 lines
1.5 KiB
Plaintext

//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
//! @file
//! @brief Add tasks to a user-provided graph
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
using namespace cuda::experimental::stf;
__global__ void dummy() {}
int main()
{
cudaGraph_t graph;
cudaGraphExec_t graphExec = NULL;
cudaStream_t stream;
cuda_safe_call(cudaStreamCreateWithFlags(&stream, cudaStreamNonBlocking));
cuda_safe_call(cudaGraphCreate(&graph, 0));
graph_ctx ctx(graph);
auto lX = ctx.token();
auto lY = ctx.token();
auto lZ = ctx.token();
ctx.task(lX.write())->*[](cudaStream_t s) {
dummy<<<1, 1, 0, s>>>();
};
ctx.task(lX.read(), lY.write())->*[](cudaStream_t s) {
dummy<<<1, 1, 0, s>>>();
};
ctx.task(lX.read(), lZ.write())->*[](cudaStream_t s) {
dummy<<<1, 1, 0, s>>>();
};
ctx.task(lY.rw(), lZ.rw())->*[](cudaStream_t s) {
dummy<<<1, 1, 0, s>>>();
};
ctx.finalize_as_graph();
cuda_safe_call(cudaGraphInstantiate(&graphExec, graph, NULL, NULL, 0));
cuda_safe_call(cudaGraphLaunch(graphExec, stream));
cuda_safe_call(cudaStreamSynchronize(stream));
}